@@ -1,5 +1,3 @@
-import os
-
 import click
 
 from blackbelt.handle_trello import migrate_label as ml, schedule_list as sl
@@ -21,9 +19,9 @@ def migrate_label(*args, **kwargs):
 
 
 @cli.command(name='schedule-list')
-@click.option('--story-card', help='Story Card ID or shortlink')
 @click.option('--story-list', help='Name of the list that should be converted to cards')
 @click.option('--owner', help='Whom to assign a created work card')
 @click.option('--label', help='Assign a label to the newly-created card. For now, label must be a color name.')
+@click.argument('story_card')
 def schedule_list(**kwargs):
     sl(**kwargs)
