@@ -21,5 +21,5 @@ class TestBuildInfoRetrieval(object):
         except ValueError:
             raise SkipTest()
 
-    def test_posting_message(self):
-        self.client.post_message("Testing HipChat Messages in Black Belt Exploratory Test Suite")
+    # def test_posting_message(self):
+    #     self.client.post_message("Testing HipChat Messages in Black Belt Exploratory Test Suite")
